Hungarian NC 2010 Budapest, Hungary November 13th 2010 3R+F 38 players Martin Major (Mephistopheles) Deck Name: mINIMAL sTYLE Fast and aggressive rush combat. Make 1st vp asap and decide who to stay 1 on 1 with. Follow the basic combat doctrine to backrush first and then play without a predator. /could need more copies of Animalism skill card. Fear of Mekhet was a metagame choice and burned a Legendary Unmada. Wider View never showed up when needed. Frontal Assault is pure gold!/ /my version is really not about blocking. Random intercept is good to keep people guessing and blocking deflected bleeds/ /very solid combat package, Target Vitals and Terror Frenzy are extremely useful/ /discarded when drawn to early and taken back into hand after a completed Ashur Cycle in the midgame. Awesome bonus to your ousting power/ Crypt (12 cards, min=8, max=32, avg=4.5) ---------------------------------------- 4x Nana Buruku 8 ANI POT PRE Guruhi:4 1x Beetleman 4 ANI obf Nosferatu:4 1x Bobby Lemon 4 ANI pro Gangrel:3 1x Bothwell 3 ani for Gangrel:3 1x Clarissa Steinburgen 3 ani obf Nosferatu:3 1x Stick 3 ANI Nosferatu antitribu:4 1x Mouse 2 ani Nosferatu:3 1x Zip 2 ani Ravnos:3 1x Lisa Noble 1 ani Caitiff:3 Library (76 cards) Master (21; 1 trifle) 3x Animalism 9x Ashur Tablets 2x Blood Doll 2x Fame 1x Fear of Mekhet 1x Frontal Assault 1x Pentex(TM) Subversion 1x Powerbase: Montreal 1x Wider View Action (13) 13x Deep Song -- just the right number Reaction (8) 2x Cats' Guidance 1x Delaying Tactics 3x On the Qui Vive 2x Sense the Savage Way Combat (33) 10x Aid from Bats 2x Canine Horde 10x Carrion Crows 4x Target Vitals 5x Taste of Vitae 2x Terror Frenzy Event (1) 1x Dragonbound